the_stars
The Stars is a terminal styling and logging library inspired by Lipgloss, a Golang library.
It is mainly for printing out text in the terminal with styles such as colors, bolding, underlining, etc.
Install
To add this library to your project, run the following command:
gleam add the_stars
Usage
More examples of usages can be found in the examples directory.